.. :changelog:

History
=======

1.0.0 (2016-06-30)
------------------
* First version

1.0.1 (2016-10-07)
------------------
* Bug setup correction

1.1.0 (2018-15-02)
------------------
* Adding IO functions
* Rebase
* Dot display method

1.2.0 (2018-22-02)
------------------
* Adding dot export for Automata
* Adding yalm and json import and export for Automata and Hankel
* Adding random SVD as an option for dense Hankel matrix calculation.
* Rebase : removing Learning class + some new functionnalities
* Update doc.
